JupyterHub Narratives
=====================

.. contents:: Contents
   :local:

Description
-----------

JupyterHub Narratives explore deployment and scaling of the Jupyter Notebook
for a group of users. JupyterHub allows flexibility in configuration and
deployment which makes JupyterHub valuable to education, industry research
teams, and service providers. In these Narratives, we will look at
differences in deployment, deployment advantages, and best practices.

Narrative examples
------------------

- A basic JupyterHub deployment
- A `reference deployment of JupyterHub using Docker <https://github.com/jupyterhub/jupyterhub-deploy-docker>`_
- Teaching a Course with JupyterHub and nbgrader using a
  `reference deployment on a single server and Ansible scripts <https://github.com/jupyterhub/jupyterhub-deploy-teaching>`_
  to automate set up
- Teaching a Course with JupyterHub, nbgrader, and containers
- JupyterHub deployments using Containers including Docker

.. note::

    We're actively working on this section of the documentation to improve
    it for you. Thanks for your patience.
